@@ -26,6 +26,7 @@
 
 using System;
 using System.IO;
+using System.Text.RegularExpressions;
 
 namespace Tomboy
 {
@@ -119,7 +120,8 @@ namespace Tomboy
 
 		public virtual void DisplayHelp (string help_uri, Gdk.Screen screen)
 		{
-			OpenUrl ("http://library.gnome.org/users/tomboy/0.12/", screen);
+			Match version = Regex.Match (Defines.VERSION, @"^\d+\.\d+");
+			OpenUrl (string.Format("http://library.gnome.org/users/tomboy/{0}/", version.Value), screen);
 		}
 
 		#endregion
